@@ -95,35 +95,35 @@ extern Data                      data;
 extern Lum::Model::CalendarRef   date;
 extern Lum::Model::TimeRef       timestamp;
 
-extern Lum::Model::SizeTRef      currentTab;
+extern Lum::Model::ULongRef      currentTab;
 
 // Weight range of diagram
-extern Lum::Model::SizeTRef      topWeight;
-extern Lum::Model::SizeTRef      bottomWeight;
+extern Lum::Model::ULongRef      topWeight;
+extern Lum::Model::ULongRef      bottomWeight;
 // Weight limit for "good" values in diagram
-extern Lum::Model::SizeTRef      maxWeight;
-extern Lum::Model::SizeTRef      minWeight;
+extern Lum::Model::ULongRef      maxWeight;
+extern Lum::Model::ULongRef      minWeight;
 
 // Value range of diagram
-extern Lum::Model::SizeTRef      topValue;
-extern Lum::Model::SizeTRef      bottomValue;
+extern Lum::Model::ULongRef      topValue;
+extern Lum::Model::ULongRef      bottomValue;
 // Value limit for "good" values in diagram
-extern Lum::Model::SizeTRef      maxValue;
-extern Lum::Model::SizeTRef      minValue;
+extern Lum::Model::ULongRef      maxValue;
+extern Lum::Model::ULongRef      minValue;
 
 // Valze limit for "good" values in food list
-extern Lum::Model::SizeTRef      goodValueLimit;
-extern Lum::Model::SizeTRef      badValueLimit;
+extern Lum::Model::ULongRef      goodValueLimit;
+extern Lum::Model::ULongRef      badValueLimit;
 
 // Start value for trend
-extern Lum::Model::SizeTRef      refValue;
+extern Lum::Model::ULongRef      refValue;
 
 extern Lum::Model::StringRef     valueUnit;
 extern Lum::Model::StringRef     weightUnit;
 
 // trend type
-extern Lum::Model::SizeTRef      trendType;
-extern Lum::Model::SizeTRef      trendDirection;
+extern Lum::Model::ULongRef      trendType;
+extern Lum::Model::ULongRef      trendDirection;
 
 extern bool LoadConfig(const std::wstring& file);
 
