@@ -298,7 +298,7 @@ DataInput::DataInput()
    entries(new EntryModel(new EntryComparator())),
    entrySelection(new Lum::Model::SingleLineSelection()),
 
-   trend(new Lum::Model::Int(Trend::none))
+   trend(new Lum::Model::Long(Trend::none))
 {
   date->SetToCurrent();
 
