@@ -247,7 +247,8 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
          ++entry) {
       if (entry->item.empty()) {
         // Draw weight points and connect points by lines
-        if (entry->amount>maxWeight->Get() || entry->amount<minWeight->Get()) {
+        if (entry->amount>maxWeight->Get() ||
+            entry->amount<minWeight->Get()) {
           draw->PushForeground(warnColor);
         }
         else {
@@ -277,7 +278,7 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
           lx2=cx;
           ly2=cy;
 
-          if (!(lx1<this->x && lx2<this->x)) {
+          if (!(lx1<this->x && lx2<this->x) && cx!=px) {
             // Point outside diagram: Interpolate position on left diagram border
             if (lx1<this->x) {
               lx1=this->x;
@@ -490,13 +491,19 @@ void Diagram::SyncGraphWithDate()
   }
 
   if (date->Get()<data.GetStartDate()) {
-    GetHAdjustment()->ShowFirstPage();
+    if (GetHAdjustment()!=NULL && GetHAdjustment()->IsValid()) {
+      GetHAdjustment()->ShowFirstPage();
+    }
   }
   else if (date->Get()>data.GetEndDate()) {
-    GetHAdjustment()->ShowLastPage();
+    if (GetHAdjustment()!=NULL && GetHAdjustment()->IsValid()) {
+      GetHAdjustment()->ShowLastPage();
+    }
   }
   else {
-    GetHAdjustment()->CenterOn((date->Get()-data.GetStartDate())*GetDayWidth()+GetDayWidth()/2+1);
+    if (GetHAdjustment()!=NULL && GetHAdjustment()->IsValid()) {
+      GetHAdjustment()->CenterOn((date->Get()-data.GetStartDate())*GetDayWidth()+GetDayWidth()/2+1);
+    }
   }
 }
 
