@@ -80,7 +80,10 @@ public:
   //bool SetModel(Lum::Base::Model* model);
 
   void CalcSize();
-  void Draw(int x, int y, size_t w, size_t h);
+  void GetDimension(size_t& width, size_t& height);
+  void Layout();
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
 
